@@ -25,7 +25,8 @@ except ImportError:
 try:
     unittest.installHandler
 except AttributeError:
-    raise ImportError("Built-in unittest version too old, unittest2 is required")
+    raise ImportError(
+        "Built-in unittest version too old, unittest2 is required")
 
 __unittest = True
 
