@@ -20,6 +20,7 @@ __unittest = True
 
 
 class PrintHooks(events.Plugin):
+
     """Print hooks as they are called"""
 
     configSection = 'print-hooks'
@@ -44,6 +45,7 @@ class PrintHooks(events.Plugin):
 
 
 class NoisyHook(events.Hook):
+
     def __call__(self, event):
         _report(self.method, event)
         _indent()
@@ -54,7 +56,7 @@ class NoisyHook(events.Hook):
 
 
 def _report(method, event):
-    print >> sys.stderr, "\n%s%s: %s" % (''.join(INDENT), method, event)
+    sys.stderr.write("\n%s%s: %s" % (''.join(INDENT), method, event))
 
 
 def _indent():
